<?php
/**
 * Simple Application Component that allows you to send SMS using SMSConneXion Gateway easily
 * @author Celusion Technologies <support@celusion.com>
 * @copyright Celusion Technologies
 * @link 
 * @license BSD
 * 
 * @todo Make better use of Yii framework integration
 * @todo Improve documentation
 * @todo Improve error handling
 * @todo a spring clean
 */

class SMSConneXion extends CApplicationComponent
{
	/**
     * The username for the SMSConnexion API
     * @var string
     */
    public $smxUsername;

    /**
     * The password for the SMSConnexion API
     * @var string
     */
    public $smxPassword;

    /**
     * The API Secret Key for this product.
     * @var string
     */
    public $smxSecret;
	
    protected $url = 'http://smsc.smsconnexion.com/api/gateway.aspx';
	
	public function __construct($smxUsername = null, $smxPassword = null, $smxSecret = null)
    {
		$this->smxUsername = $smxUsername;
        $this->smxPassword = $smxPassword;
        $this->smxSecret = $smxSecret;
    }

    public function init()
    {
		if ( ! function_exists ( 'curl_init' ) )
			throw new CException ( 'No cURL' );
		if(! $this->licence()){
            throw new CException ( "You don't have the license to run the SMS ConneXion module or License Key is Invalid. Contact support@celusion.com ");
        }		
		parent::init();
    }
	
    public function sendSMS( $data ) {
	  
		$data["action"] = "send";
        $data["username"] = $this->smxUsername;	
        $data["passphrase"]= $this->smxPassword;
		if($data['to']){
			if(is_array ( $data['to'] ))
				$data["phone"]= implode(",",$data['to']);
			else
				$data["phone"]= $data['to'];
			$data["message"]= $data['message'];
		    $result = $this->request($data);		
		}else
        	return "To field is empty.";	
	    return "Message Send.";
	}
	
	public function getBalance() {
	
		$data["action"] = "getbalance";
        $data["username"] = $this->smxUsername;	
        $data["passphrase"]= $this->smxPassword;
		$response = $this->request($data);
		$response = explode(',', $response);
		$result['user_type'] = $this->get_account_type($response[0]);
		$result['user_balance'] = $response[1];
		return $result;
	}
	
	protected function licence ()
	{
	    $license = $this->smxSecret;	
		$url =  'http://smsc.smsconnexion.com/license/magento/' . $license . '.txt';
		$exists = file_get_contents($url);
		$domain = $_SERVER['HTTP_HOST'];
	    if (empty($exists)) {      			
			return FALSE;
        }
		$exists = str_replace('Celusion_SMSConneXion@http://','',$exists);
		if (trim($domain) != trim($exists)) {               	
			return FALSE;											
        }
		return TRUE;
	}
	
	protected function get_account_type($type)
    {	 				 
		if($type==1)
			$value = 'Prepaid User';			
		else if($type == 2)
			$value = 'Postpaid User';
		else	
			$value = 'Missing Parameter';			
		return $value;
    }
	
	protected function request ( array $params = array ( ) )
	{
		$ch = curl_init();
        $url =  $this->url;
	    curl_setopt($ch,CURLOPT_URL,$url);
	    curl_setopt($ch,CURLOPT_POSTFIELDS,$params);
	    curl_setopt($ch,CURLOPT_CONNECTTIMEOUT,10); # timeout after 10 seconds, you can increase it
		curl_setopt ($ch, CURLOPT_RETURNTRANSFER, 1);  # Set curl to return the data instead of printing it to the browser.
	    curl_setopt($ch,  CURLOPT_USERAGENT , "Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.1)"); # Some server may refuse your request if you dont pass 
	    $result = curl_exec($ch);
	    curl_close($ch);
		return $result;
	}

	
}
